=======
History
=======


0.1.3 (2019-07-08)
------------------

* Allow .send to a list of receivers.
* Allow to receive messages with lists of lists.
* Fixed readme.

0.1.1 (2019-06-18)
------------------

* Moved from pyson to python-agentspeak
* Added some helpers like pause_bdi, resume_bdi. 
* Now the asl file in the constructor is mandatory.
* Allow to send tell messages with no args.
* Allow sending messages with variables.
* Extended the examples.

0.1.0 (2019-03-09)
------------------

* First release on PyPI.
